<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Order;
use App\Models\OrderItem;
use App\Models\Product;

class OrderController extends Controller
{
    public function generateRandomString($length = 10)
    {
        return rand(100000, 999999);
    }

    public function confirmOrder(Request $request)
    {
        $request->validate([
            'name' => 'required|string',
            'email' => 'required|email',
            'address' => 'required|string',
            'product_ids' => 'required|array',
            'quantity' => 'required|array',
        ]);

        $productIds = $request->input('product_ids');
        $quantities = $request->input('quantity');

        $total = 0;
        $orderDetails = [];

        $orderRefId = $this->generateRandomString(8);

        foreach ($productIds as $key => $productId) {
            $product = Product::find($productId);

            if ($product) {
                $subtotal = $product->price * $quantities[$key];
                $total += $subtotal;

                $orderDetails[] = [
                    'order_id' => $orderRefId, 
                    'product_id' => $productId,
                    'quantity' => $quantities[$key],
                    'subtotal' => $subtotal,
                ];
            }
        }

        $order = new Order([
            'order_ref_id' => $orderRefId,
            'order_at' => now(),
            'name' => $request->input('name'),
            'email' => $request->input('email'),
            'address' => $request->input('address'),
            'order_amount' => $total,
        ]);

        $order->save();
       

        $order->orderItems()->createMany($orderDetails);

        $orderDetails['total'] = $total;
           session()->forget('cart');

        return redirect()->route('thank-you', ['orderRefId' => $orderRefId]);
    }
}
