<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Product;
use App\Models\OrderItem;

class ProductsController extends Controller
{
    public function showCartTable()
    {
        $products = Product::all();

        return view('cart', compact('products'));
    }

    public function cartCount()
    {
        $cart = session()->get('cart', []);
        $count = count($cart);
        return response()->json(['count' => $count]);
    }
    
    public function addToCart($id)
    {
        $product = Product::find($id);

        if (!$product) {

            abort(404);

        }

        $cart = session()->get('cart',[]);

        if (!$cart) {

            $cart = [
                $id => [
                    "name" => $product->name,
                    "quantity" => 1,
                    "price" => $product->price,
                    "photo" => $product->photo
                ]
            ];

            session()->put('cart', $cart);

            return redirect()->back()->with('success', 'Product added to cart successfully!');
        }

        if (isset($cart[$id])) {

            $cart[$id]['quantity']++;

            session()->put('cart', $cart);

            return redirect()->back()->with('success', 'Product added to cart successfully!');

        }

        $cart[$id] = [
            "name" => $product->name,
            "quantity" => 1,
            "price" => $product->price,
            "photo" => $product->photo
        ];

        session()->put('cart', $cart);
        if(request()->wantsJson()) {
            return response()->json(['message' => 'Product added to cart successfully!']);
        }

        return redirect()->back()->with('success', 'Product added to cart successfully!');
    }

    public function updateCart(Request $request)
{
    $id = $request->id;
    $newQuantity = $request->quantity;

    $cart = session()->get('cart');

    if ($cart && isset($cart[$id])) {
        $cart[$id]['quantity'] = $newQuantity;

        session()->put('cart', $cart);

        $details = $cart[$id];
        $subtotal = $details['price'] * $newQuantity;

        $total = collect($cart)->sum(function ($item) {
            return $item['price'] * $item['quantity'];
        });

        return response()->json(['success' => true, 'subtotal' => $subtotal, 'total' => $total]);
    }

    return response()->json(['success' => false]);
}



    public function removeCartItem(Request $request)
    {
        if ($request->id) {

            $cart = session()->get('cart');

            if (isset($cart[$request->id])) {

                unset($cart[$request->id]);

                session()->put('cart', $cart);
            }

            session()->flash('success', 'Product removed successfully');
        }
    }

    public function clearCart()
{
    session()->forget('cart');
    return redirect()->back();
}
public function showProducts()
{
    $products = Product::all();
    return view('welcome', compact('products'));}


    public function proceed()
    {
        $products = Product::all();

        return view('checkout', compact('products'));
    }

    public function index(Request $request)
    {
        $orderRefId = $request->input('orderRefId'); // Get the orderRefId from the request

        return view('thankyou', compact('orderRefId'));
    }


}


