<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Laravel Products</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="preconnect" href="https://fonts.bunny.net">
    <link href="https://fonts.bunny.net/css?family=figtree:400,600&display=swap" rel="stylesheet" />
    <link rel="stylesheet" href="{{ asset('css/style.css') }}">
</head>
<body>
    @extends('layout')
    @section('title', 'Products')
    @section('content')
    <table id="cart" class="table table-bordered table-hover table-condensed mt-3">
        <thead>
            <tr>
                <th style="width:50%">Product</th>
                <th style="width:8%" class="text-center">Price</th>
                <th style="width:8%">Quantity</th>
                <th style="width:22%" class="text-center">Subtotal</th>
            </tr>
        </thead>
        <tbody>
            <?php $total = 0 ?>
            @if(session('cart'))
            @foreach(session('cart') as $id => $details)
            <?php $total += $details['price'] * $details['quantity'] ?>
            <tr>
                <td data-th="Product">
                    <div class="row">
                        <div class="col-sm-3 hidden-xs"><img src="{{ $details['photo'] }}" width="50" height=""
                                class="img-responsive" />
                        </div>
                        <div class="col-sm-9">
                            <p class="nomargin">{{ $details['name'] }}</p>
                            <p class="remove-from-cart cart-delete" data-id="{{ $id }}" title="Delete">Remove</p>
                        </div>
                    </div>
                </td>
                <td data-th="Subtotal" class="text-center">{{ $details['price'] }}</td>
                <td data-th="Quantity">
                    <input type="number" value="{{ $details['quantity'] }}" class="form-control quantity" />
                </td>
                <td data-th="Subtotal" class="text-center">${{ number_format($details['price'] * $details['quantity'], 2) }}</td>
            </tr>
            @endforeach
            @endif
        </tbody>
        <tfoot>
            @if(!empty($details))
            <tr class="visible-xs">
                <td class="text-right" colspan="3"><strong>Total</strong></td>
                <td class="text-center">${{ number_format($total, 2) }}</td>
            </tr>
            @else
            <tr>
                <td class="text-center" colspan="4">Your Cart is Empty.....</td>
            <tr>
                @endif
        </tfoot>
    </table>
    <a href="{{ url('http://127.0.0.1:8000/') }}" class="btn shopping-btn">Continue Shopping</a>
    <a href="{{ url('checkout') }}" class="btn btn-warning check-btn">Proceed Checkout</a>
    <div class="container products">
        <div class="row">
            @foreach($products as $product)
            <div class="col-xs-12 col-sm-6 col-md-4">
                <div class="card mb-4">
                    <img src="{{ $product->photo }}" class="card-img-top img-size" alt="{{ $product->name }}">
                    <div class="card-body">
                        <h5 class="card-title">{{ $product->name }}</h5>
                        <p class="card-text">{{ \Illuminate\Support\Str::limit($product->description, 50) }}
                        </p>
                        <p class="card-text"><strong>Price: </strong> ${{ $product->price }}</p>
                        <a href="{{ url('add-to-cart/'.$product->id) }}" class="btn btn-warning btn-block text-center"
                            role="button">Add to cart</a>
                    </div>
                </div>
            </div>
            @endforeach
        </div>
    </div>
    @endsection

@section('scripts')
<script type="text/javascript">
    $(".remove-from-cart").click(function (e) {
        e.preventDefault();
        var ele = $(this);
        if (confirm("Are you sure want to remove product from the cart?")) {
            $.ajax({
                url: '{{ url('remove-from-cart') }}',
                method: "DELETE",
                data: { _token: '{{ csrf_token() }}', id: ele.attr("data-id") },
                success: function (response) {
                    window.location.reload();
                }
                });
            }
        });

        $(document).ready(function() {
            $(".quantity").on('input', function() {
                var newQuantity = $(this).val();
                var row = $(this).closest('tr');
                var id = row.find('.cart-delete').data('id');

                $.ajax({
                    url: '{{ url('update-cart') }}', 
                    method: "PATCH",
                    data: {
                        _token: '{{ csrf_token() }}',
                        id: id,
                        quantity: newQuantity
                    },
                    success: function(response) {
                        if (response.success) {
                            row.find('td[data-th="Subtotal"]').text('$' + response.subtotal);
                            $('.visible-xs').find('.text-center').text('$' + response.total);
                        } else {
                            alert('Failed to update quantity in the cart.');
                        }
                    },
                    error: function() {
                        alert('Error occurred while updating quantity.');
                    }
                });
            });
        });
</script>
@endsection
</body>
</html>